/* Changes all events upon MIDI channel 1 to MIDI channel 10.
 */

OPTIONS "C_CALL LABELCHECK NOSOURCE"

/* Add the REXX GUI and RxMidi functions. */
LIBRARY rexxgui, rxmidi

/* Trap errors in RxMidi functions. So, we don't have to check the return values
 * from MIDI REXX functions that set the ERROR condition, such as MIDISetEvent().
 */
MidiErr = "ERROR"
MidiHeading = 1

/* Print an introduction. */
IF GuiSay('This script changes all events upon MIDI channel 1 to MIDI channel 10. Proceed?', 'YES|INFO', 'New MIDI') \= 'YES' THEN SIGNAL out

/* Check if we have a MIDI file name. We get the filename from
 * the command line (ie, the user typed it after disasm.rex), or
 * if not supplied, we bring up the file dialog.
 */
IF ARG() < 1 THEN DO
	error = GuiFile('FromFilename', 'EXISTING', 'Enter a name for the new MIDI file', 'MIDI files (*.mid, *.rmi) | *.mid;*.rmi | All files (*.*) | *.*')
	IF error \== "" THEN RETURN
END
ELSE FromFilename = ARG(1)

DO
	/* Open a MIDI file */
	MIDIOpenFile(FromFilename)

	/* Move to the start of the next track */
	DO WHILE MIDITrack("") \= 0

		/* For each Voice category event in this track on channel 1 or 10... */
		DO WHILE MIDIGetEvent('On N|Off |(Off|Afte|Cont|Prog|Poly|Pitc', '1|10') == ""

			/* Is it on channel 10? Switch to 1 */
			IF MIDIEvent.!Channel == 10 THEN MIDIEvent.!Channel = 1

			/* Switch 1 to 10 */
			ELSE MIDIEvent.!Channel = 10

			MIDISetEvent('CHAN')

		END /* DO WHILE MIDIGetEvent */

	END /* DO UNTIL MIDITrack */

	/* Save to a MIDI file with an underscore prepended to the name */
	name = FILESPEC('N', FromFilename)
	path = LEFT(FromFilename, LENGTH(FromFilename) - LENGTH(name))
	MIDISaveFile(path || '_' || name)

	CATCH ERROR
		CONDITION('M')
END
RETURN
